<?php
class ControladorDirecciones{

    static public function ctrCrearDireccion(){
        
        
        if(isset($_POST['direccion'], $_POST['idZona'])){
            if(!empty($_POST['direccion']) && !empty($_POST['idZona'])){
                $idzona = $_POST['idZona'];
                $direccion = $_POST['direccion'];
                $respuesta = ModeloDirecciones::mdlCrearDireccion($idzona, $direccion);
               
                if($respuesta == "ok"){
                    ControladorDirecciones::ejecurarAlerta("Registro con exito","direcciones");
                
                }
            }
        }
    }

    static public function ctrConsultarDireccionId($id){
        $tabla = "direcciones_zona";
        $item = "iddireccion";
        $consulta = ModeloDirecciones::mdlConsultarZonaId($tabla, $item, $id);
        return $consulta;
    }

    static public function ctrEditarDireccion(){
        if(isset($_POST['updateiddireccion'], $_POST['editarDireccion'], $_POST['updateIdZona'])){
            if(!empty($_POST['updateiddireccion']) && !empty($_POST['editarDireccion']) && !empty($_POST['updateIdZona'])){
                $datos = [
                    "nombre" => $_POST['editarDireccion'],
                    "id_zona" => $_POST['updateIdZona'],
                    "iddireccion" => $_POST['updateiddireccion']
                ];
                $update = ModeloDirecciones::mdlEditarDireccion($datos);
                if($update == "ok"){
                    ControladorDirecciones::ejecurarAlerta("dirección editada con exito","direcciones");
                }
            }
        }
    }

    static public function ctrMostrarDireccion(){
        $tabla = "direcciones_zona";
        $consulta = ModeloDirecciones::mdlMostrarUbicacion($tabla);
        return $consulta;
    }

    static public function ctrCrearZona(){
        if(isset($_POST['zona'])){
            if(!empty($_POST['zona'])){

                $zona = $_POST['zona'];
               
                $respuesta = ModeloDirecciones::mdlCrearZona($zona);
                if($respuesta == "ok"){
                    ControladorDirecciones::ejecurarAlerta("Registro con exito","zonas");
                
                }
            }
            
        }
        
    }

    static public function ctrEditarZona(){
        if(isset($_POST['editarZona'],$_POST['idzona'] )){
            if(!empty($_POST['editarZona']) && !empty($_POST['idzona'])){
                $editarZona = $_POST['editarZona'];
                $datos = [
                    "nombre" => $editarZona,
                    "id" => $_POST['idzona']
                ];
                $update = ModeloDirecciones::mdlEditarZona($datos);
                if($update == "ok"){
                    ControladorDirecciones::ejecurarAlerta("Zona editada con exito","zonas");
                }
            }
        }
    }

    static public function ctrMostrarZona(){
        $tabla = "zona";
        $consulta = ModeloDirecciones::mdlMostrarUbicacion($tabla);
        return $consulta;
    }

    static public function ctrConsultarZonaId($id){
        $tabla = "zona";
        $item = "idzona";
        $consulta = ModeloDirecciones::mdlConsultarZonaId($tabla, $item, $id);
        return $consulta;
    }

    static public function ctrEliminarZona($id){
        $tabla = "zona";
        $item = "idzona";
        $eliminar = ModeloDirecciones::mdlEliminar($tabla, $item, $id);
        return $eliminar;
    }

    static public function ctrEliminarDireccion($id){
        $tabla = "direcciones";
        $item = "iddireccion";
        $eliminar = ModeloDirecciones::mdlEliminar($tabla, $item, $id);
        return $eliminar;
    }

    // funcion para ejecutar un alerta si el registro fue exitoso o fallido
    static public function ejecurarAlerta($message, $url = null, $estado = "success"){
        $alerta = '<script>
                        swal({
                            type: "'.$estado.'",
                            title: "'.$message.'",
                            showConfirmButton: true,
                            confirmButtonText: "Cerrar"
                            }).then(function(result){
                                        ';
        if($url != null){
            $alerta .= ' if (result.value) {
                    window.location = "'.$url.'";
                }
            })
            </script>';
        } else {
            $alerta .= ' 
                })
                </script>';
        }
        echo $alerta;
    }
}